/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.asset.category.property.service;

import org.osgi.annotation.versioning.ProviderType;
import org.osgi.framework.Bundle;
import org.osgi.framework.FrameworkUtil;
import org.osgi.util.tracker.ServiceTracker;

/**
 * Provides the local service utility for AssetCategoryProperty. This utility wraps
 * <code>com.liferay.asset.category.property.service.impl.AssetCategoryPropertyLocalServiceImpl</code> and
 * is an access point for service operations in application layer code running
 * on the local server. Methods of this service will not have security checks
 * based on the propagated JAAS credentials because this service can only be
 * accessed from within the same VM.
 *
 * @author Brian Wing Shun Chan
 * @see AssetCategoryPropertyLocalService
 * @generated
 */
@ProviderType
public class AssetCategoryPropertyLocalServiceUtil {

	/*
	 * NOTE FOR DEVELOPERS:
	 *
	 * Never modify this class directly. Add custom service methods to <code>com.liferay.asset.category.property.service.impl.AssetCategoryPropertyLocalServiceImpl</code> and rerun ServiceBuilder to regenerate this class.
	 */

	/**
	 * Adds the asset category property to the database. Also notifies the appropriate model listeners.
	 *
	 * @param assetCategoryProperty the asset category property
	 * @return the asset category property that was added
	 */
	public static
		com.liferay.asset.category.property.model.AssetCategoryProperty
			addAssetCategoryProperty(
				com.liferay.asset.category.property.model.AssetCategoryProperty
					assetCategoryProperty) {

		return getService().addAssetCategoryProperty(assetCategoryProperty);
	}

	public static
		com.liferay.asset.category.property.model.AssetCategoryProperty
				addCategoryProperty(
					long userId, long categoryId, String key, String value)
			throws com.liferay.portal.kernel.exception.PortalException {

		return getService().addCategoryProperty(userId, categoryId, key, value);
	}

	/**
	 * Creates a new asset category property with the primary key. Does not add the asset category property to the database.
	 *
	 * @param categoryPropertyId the primary key for the new asset category property
	 * @return the new asset category property
	 */
	public static
		com.liferay.asset.category.property.model.AssetCategoryProperty
			createAssetCategoryProperty(long categoryPropertyId) {

		return getService().createAssetCategoryProperty(categoryPropertyId);
	}

	/**
	 * Deletes the asset category property from the database. Also notifies the appropriate model listeners.
	 *
	 * @param assetCategoryProperty the asset category property
	 * @return the asset category property that was removed
	 */
	public static
		com.liferay.asset.category.property.model.AssetCategoryProperty
			deleteAssetCategoryProperty(
				com.liferay.asset.category.property.model.AssetCategoryProperty
					assetCategoryProperty) {

		return getService().deleteAssetCategoryProperty(assetCategoryProperty);
	}

	/**
	 * Deletes the asset category property with the primary key from the database. Also notifies the appropriate model listeners.
	 *
	 * @param categoryPropertyId the primary key of the asset category property
	 * @return the asset category property that was removed
	 * @throws PortalException if a asset category property with the primary key could not be found
	 */
	public static
		com.liferay.asset.category.property.model.AssetCategoryProperty
				deleteAssetCategoryProperty(long categoryPropertyId)
			throws com.liferay.portal.kernel.exception.PortalException {

		return getService().deleteAssetCategoryProperty(categoryPropertyId);
	}

	public static void deleteCategoryProperties(long entryId) {
		getService().deleteCategoryProperties(entryId);
	}

	public static void deleteCategoryProperty(
		com.liferay.asset.category.property.model.AssetCategoryProperty
			categoryProperty) {

		getService().deleteCategoryProperty(categoryProperty);
	}

	public static void deleteCategoryProperty(long categoryPropertyId)
		throws com.liferay.portal.kernel.exception.PortalException {

		getService().deleteCategoryProperty(categoryPropertyId);
	}

	/**
	 * @throws PortalException
	 */
	public static com.liferay.portal.kernel.model.PersistedModel
			deletePersistedModel(
				com.liferay.portal.kernel.model.PersistedModel persistedModel)
		throws com.liferay.portal.kernel.exception.PortalException {

		return getService().deletePersistedModel(persistedModel);
	}

	public static com.liferay.portal.kernel.dao.orm.DynamicQuery
		dynamicQuery() {

		return getService().dynamicQuery();
	}

	/**
	 * Performs a dynamic query on the database and returns the matching rows.
	 *
	 * @param dynamicQuery the dynamic query
	 * @return the matching rows
	 */
	public static <T> java.util.List<T> dynamicQuery(
		com.liferay.portal.kernel.dao.orm.DynamicQuery dynamicQuery) {

		return getService().dynamicQuery(dynamicQuery);
	}

	/**
	 * Performs a dynamic query on the database and returns a range of the matching rows.
	 *
	 * <p>
	 * Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to <code>com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS</code> will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not <code>com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS</code>), then the query will include the default ORDER BY logic from <code>com.liferay.asset.category.property.model.impl.AssetCategoryPropertyModelImpl</code>. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	 * </p>
	 *
	 * @param dynamicQuery the dynamic query
	 * @param start the lower bound of the range of model instances
	 * @param end the upper bound of the range of model instances (not inclusive)
	 * @return the range of matching rows
	 */
	public static <T> java.util.List<T> dynamicQuery(
		com.liferay.portal.kernel.dao.orm.DynamicQuery dynamicQuery, int start,
		int end) {

		return getService().dynamicQuery(dynamicQuery, start, end);
	}

	/**
	 * Performs a dynamic query on the database and returns an ordered range of the matching rows.
	 *
	 * <p>
	 * Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to <code>com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS</code> will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not <code>com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS</code>), then the query will include the default ORDER BY logic from <code>com.liferay.asset.category.property.model.impl.AssetCategoryPropertyModelImpl</code>. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	 * </p>
	 *
	 * @param dynamicQuery the dynamic query
	 * @param start the lower bound of the range of model instances
	 * @param end the upper bound of the range of model instances (not inclusive)
	 * @param orderByComparator the comparator to order the results by (optionally <code>null</code>)
	 * @return the ordered range of matching rows
	 */
	public static <T> java.util.List<T> dynamicQuery(
		com.liferay.portal.kernel.dao.orm.DynamicQuery dynamicQuery, int start,
		int end,
		com.liferay.portal.kernel.util.OrderByComparator<T> orderByComparator) {

		return getService().dynamicQuery(
			dynamicQuery, start, end, orderByComparator);
	}

	/**
	 * Returns the number of rows matching the dynamic query.
	 *
	 * @param dynamicQuery the dynamic query
	 * @return the number of rows matching the dynamic query
	 */
	public static long dynamicQueryCount(
		com.liferay.portal.kernel.dao.orm.DynamicQuery dynamicQuery) {

		return getService().dynamicQueryCount(dynamicQuery);
	}

	/**
	 * Returns the number of rows matching the dynamic query.
	 *
	 * @param dynamicQuery the dynamic query
	 * @param projection the projection to apply to the query
	 * @return the number of rows matching the dynamic query
	 */
	public static long dynamicQueryCount(
		com.liferay.portal.kernel.dao.orm.DynamicQuery dynamicQuery,
		com.liferay.portal.kernel.dao.orm.Projection projection) {

		return getService().dynamicQueryCount(dynamicQuery, projection);
	}

	public static
		com.liferay.asset.category.property.model.AssetCategoryProperty
			fetchAssetCategoryProperty(long categoryPropertyId) {

		return getService().fetchAssetCategoryProperty(categoryPropertyId);
	}

	public static
		com.liferay.asset.category.property.model.AssetCategoryProperty
			fetchCategoryProperty(long categoryId, String key) {

		return getService().fetchCategoryProperty(categoryId, key);
	}

	public static com.liferay.portal.kernel.dao.orm.ActionableDynamicQuery
		getActionableDynamicQuery() {

		return getService().getActionableDynamicQuery();
	}

	/**
	 * Returns a range of all the asset category properties.
	 *
	 * <p>
	 * Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to <code>com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS</code> will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not <code>com.liferay.portal.kernel.dao.orm.QueryUtil#ALL_POS</code>), then the query will include the default ORDER BY logic from <code>com.liferay.asset.category.property.model.impl.AssetCategoryPropertyModelImpl</code>. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	 * </p>
	 *
	 * @param start the lower bound of the range of asset category properties
	 * @param end the upper bound of the range of asset category properties (not inclusive)
	 * @return the range of asset category properties
	 */
	public static java.util.List
		<com.liferay.asset.category.property.model.AssetCategoryProperty>
			getAssetCategoryProperties(int start, int end) {

		return getService().getAssetCategoryProperties(start, end);
	}

	/**
	 * Returns the number of asset category properties.
	 *
	 * @return the number of asset category properties
	 */
	public static int getAssetCategoryPropertiesCount() {
		return getService().getAssetCategoryPropertiesCount();
	}

	/**
	 * Returns the asset category property with the primary key.
	 *
	 * @param categoryPropertyId the primary key of the asset category property
	 * @return the asset category property
	 * @throws PortalException if a asset category property with the primary key could not be found
	 */
	public static
		com.liferay.asset.category.property.model.AssetCategoryProperty
				getAssetCategoryProperty(long categoryPropertyId)
			throws com.liferay.portal.kernel.exception.PortalException {

		return getService().getAssetCategoryProperty(categoryPropertyId);
	}

	public static java.util.List
		<com.liferay.asset.category.property.model.AssetCategoryProperty>
			getCategoryProperties() {

		return getService().getCategoryProperties();
	}

	public static java.util.List
		<com.liferay.asset.category.property.model.AssetCategoryProperty>
			getCategoryProperties(long entryId) {

		return getService().getCategoryProperties(entryId);
	}

	public static
		com.liferay.asset.category.property.model.AssetCategoryProperty
				getCategoryProperty(long categoryPropertyId)
			throws com.liferay.portal.kernel.exception.PortalException {

		return getService().getCategoryProperty(categoryPropertyId);
	}

	public static
		com.liferay.asset.category.property.model.AssetCategoryProperty
				getCategoryProperty(long categoryId, String key)
			throws com.liferay.portal.kernel.exception.PortalException {

		return getService().getCategoryProperty(categoryId, key);
	}

	public static java.util.List
		<com.liferay.asset.category.property.model.AssetCategoryProperty>
			getCategoryPropertyValues(long groupId, String key) {

		return getService().getCategoryPropertyValues(groupId, key);
	}

	public static
		com.liferay.portal.kernel.dao.orm.IndexableActionableDynamicQuery
			getIndexableActionableDynamicQuery() {

		return getService().getIndexableActionableDynamicQuery();
	}

	/**
	 * Returns the OSGi service identifier.
	 *
	 * @return the OSGi service identifier
	 */
	public static String getOSGiServiceIdentifier() {
		return getService().getOSGiServiceIdentifier();
	}

	public static com.liferay.portal.kernel.model.PersistedModel
			getPersistedModel(java.io.Serializable primaryKeyObj)
		throws com.liferay.portal.kernel.exception.PortalException {

		return getService().getPersistedModel(primaryKeyObj);
	}

	/**
	 * Updates the asset category property in the database or adds it if it does not yet exist. Also notifies the appropriate model listeners.
	 *
	 * @param assetCategoryProperty the asset category property
	 * @return the asset category property that was updated
	 */
	public static
		com.liferay.asset.category.property.model.AssetCategoryProperty
			updateAssetCategoryProperty(
				com.liferay.asset.category.property.model.AssetCategoryProperty
					assetCategoryProperty) {

		return getService().updateAssetCategoryProperty(assetCategoryProperty);
	}

	public static
		com.liferay.asset.category.property.model.AssetCategoryProperty
				updateCategoryProperty(
					long userId, long categoryPropertyId, String key,
					String value)
			throws com.liferay.portal.kernel.exception.PortalException {

		return getService().updateCategoryProperty(
			userId, categoryPropertyId, key, value);
	}

	public static
		com.liferay.asset.category.property.model.AssetCategoryProperty
				updateCategoryProperty(
					long categoryPropertyId, String key, String value)
			throws com.liferay.portal.kernel.exception.PortalException {

		return getService().updateCategoryProperty(
			categoryPropertyId, key, value);
	}

	public static AssetCategoryPropertyLocalService getService() {
		return _serviceTracker.getService();
	}

	private static ServiceTracker
		<AssetCategoryPropertyLocalService, AssetCategoryPropertyLocalService>
			_serviceTracker;

	static {
		Bundle bundle = FrameworkUtil.getBundle(
			AssetCategoryPropertyLocalService.class);

		ServiceTracker
			<AssetCategoryPropertyLocalService,
			 AssetCategoryPropertyLocalService> serviceTracker =
				new ServiceTracker
					<AssetCategoryPropertyLocalService,
					 AssetCategoryPropertyLocalService>(
						 bundle.getBundleContext(),
						 AssetCategoryPropertyLocalService.class, null);

		serviceTracker.open();

		_serviceTracker = serviceTracker;
	}

}